==> python-libsbml-experimental-5.12.1.tar.gz: python-libsbml-experimental-5.12.1/base/sbml/packages/multi/validator/constraints/MultiIdentifierConsistencyConstraintsDeclared.cxx <==
/**
 * @cond doxygenLibsbmlInternal
 *
 * @file    MultiIdentifierConsistencyConstraintsDeclared.cxx
 * @brief   Declarations of constraints
 * @author  Fengkai Zhang
 * @author  SBML Team
 * 
 * <!--------------------------------------------------------------------------
 * This file is part of libSBML.  Please visit http://sbml.org for more
 * information about SBML, and the latest version of libSBML.
 *
 * Copyright (C) 2013-2016 jointly by the following organizations:
 *     1. California Institute of Technology, Pasadena, CA, USA
 *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
 *     3. University of Heidelberg, Heidelberg, Germany
 *
 * Copyright (C) 2009-2013 jointly by the following organizations: 
 *     1. California Institute of Technology, Pasadena, CA, USA
 *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
 *  
 * Copyright (C) 2006-2008 by the California Institute of Technology,
 *     Pasadena, CA, USA 
 *  
 * Copyright (C) 2002-2005 jointly by the following organizations:
 *     1. California Institute of Technology, Pasadena, CA, USA
 *     2. Japan Science and Technology Agency, Japan
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation.  A copy of the license agreement is provided
 * in the file named "LICENSE.txt" included with this software distribution
 * and also available online as http://sbml.org/software/libsbml/license.html
 * ---------------------------------------------------------------------- -->*/

addConstraint(new UniqueMultiComponentIds(MultiDupClaId, *this));

addConstraint(new UniqueSpeciesTypeInstanceIdsWithinMultiSpeciesType(MultiUnqId_SptIns, *this));

addConstraint(new UniqueSpeciesTypeComponentIndexIdsWithinMultiSpeciesType(MultiUnqId_SptCpoInd, *this));

addConstraint(new UniqueInSpeciesTypeBondIdsWithinMultiSpeciesType(MultiUnqId_InSptBnd, *this));

addConstraint(new UniqueSpeciesFeatureTypeIdsWithinMultiSpeciesType(MultiUnqId_Sft, *this));

//addConstraint(new UniquePossibleSpeciesFeatureValueIdsWithinSpeciesFeatureType(MultiUnqId_PblSpecFtrVal, *this));

addConstraint(new UniqueSpeciesFeatureIdsWithinSpecies(MultiUnqId_SpeFtr, *this));

addConstraint(new UniqueSpeciesFeatureChangeIdsWithinSpeciesTypeComponentMapInProduct(MultiUnqId_SpeFtrChg, *this));

addConstraint(new UniqueCompartmentReferenceIdsWithinCompartment(MultiUnqId_CpaRef, *this));

/** @endcond */

==> python-libsbml-experimental-5.14.0.tar.gz: python-libsbml-experimental-5.14.0/base/sbml/packages/multi/validator/constraints/MultiIdentifierConsistencyConstraintsDeclared.cxx <==
/**
 * @cond doxygenLibsbmlInternal
 *
 * @file    MultiIdentifierConsistencyConstraintsDeclared.cxx
 * @brief   Declarations of constraints
 * @author  Fengkai Zhang
 * @author  SBML Team
 * 
 * <!--------------------------------------------------------------------------
 * This file is part of libSBML.  Please visit http://sbml.org for more
 * information about SBML, and the latest version of libSBML.
 *
 * Copyright (C) 2013-2016 jointly by the following organizations:
 *     1. California Institute of Technology, Pasadena, CA, USA
 *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
 *     3. University of Heidelberg, Heidelberg, Germany
 *
 * Copyright (C) 2009-2013 jointly by the following organizations: 
 *     1. California Institute of Technology, Pasadena, CA, USA
 *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
 *  
 * Copyright (C) 2006-2008 by the California Institute of Technology,
 *     Pasadena, CA, USA 
 *  
 * Copyright (C) 2002-2005 jointly by the following organizations:
 *     1. California Institute of Technology, Pasadena, CA, USA
 *     2. Japan Science and Technology Agency, Japan
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation.  A copy of the license agreement is provided
 * in the file named "LICENSE.txt" included with this software distribution
 * and also available online as http://sbml.org/software/libsbml/license.html
 * ---------------------------------------------------------------------- -->*/

addConstraint(new UniqueMultiComponentIds(MultiDupClaId, *this));

addConstraint(new UniqueSpeciesTypeInstanceIdsWithinMultiSpeciesType(MultiUnqId_SptIns, *this));

addConstraint(new UniqueSpeciesTypeComponentIndexIdsWithinMultiSpeciesType(MultiUnqId_SptCpoInd, *this));

addConstraint(new UniqueInSpeciesTypeBondIdsWithinMultiSpeciesType(MultiUnqId_InSptBnd, *this));

addConstraint(new UniqueSpeciesFeatureTypeIdsWithinMultiSpeciesType(MultiUnqId_Sft, *this));

addConstraint(new UniqueSubListOfSpeciesFeaturesIdsWithinSpecies(MultiUnqId_SubListOfSfs, *this));

addConstraint(new UniqueSpeciesFeatureIdsWithinSpecies(MultiUnqId_SpeFtr, *this));

addConstraint(new UniqueCompartmentReferenceIdsWithinCompartment(MultiUnqId_CpaRef, *this));

/** @endcond */
